CoolClip
========

Clip the cooler file to a small subset within specified regions.
Used for create example dataset for
cooler_ based software test/debug/demonstration.

    I want to extract a small subset of
    .cooler file
    and create a new one, but found cooler not support that.

    So this is a small tool for clip the cooler file.

    Maybe cooler will support this in the feature,
    this will be deprecated.

Install
-------

.. code-block:: bash

    $ pip install coolclip

Usage
-----

.. code-block:: bash

    $ coolclip --help


.. _cooler: https://github.com/mirnylab/cooler

